sortedl1.Slope
==============

.. currentmodule:: sortedl1

.. autoclass:: Slope
   :members:
   :show-inheritance:
   :inherited-members:
   :special-members: __call__, __add__, __mul__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Slope.cv
      ~Slope.fit
      ~Slope.get_metadata_routing
      ~Slope.get_params
      ~Slope.path
      ~Slope.predict
      ~Slope.set_params
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Slope.DType
   
   